==> likepoint_payment-0.0.2.tar.gz: lib/middle_ware/middle_payment.dart <==
import 'dart:convert';

import 'package:http/http.dart' as http;
import 'package:likepoint_payment/app_config.dart';

abstract class HTTP {
  Future apiCreateOrder(
      {String phone, String amount, String bu, String billCode, String title});
  Future apiSendConfirm({String phoneNumber, String operations, String otp});
  Future apiCheckConfirm({String operations});
}

class CallHTTP implements HTTP {
  Future apiCreateOrder(
      {String phone,
      String amount,
      String bu,
      String billCode,
      String title}) async {
    var client = http.Client();
    try {
      final response = await http.post(Env.apiHCS + 'createOrder', body: {
        "phoneNumber": phone,
        "amount": amount,
        "BU": bu,
        "billcode": billCode,
        "title": title,
      });
      var body = json.decode(response.body);
      return body;
    } catch (e) {
      print(e);
    } finally {
      client.close();
    }
  }

  Future apiSendConfirm({
    String phoneNumber,
    String operations,
    String otp,
  }) async {
    var client = http.Client();
    try {
      final response = await http.post(Env.apiHCS + 'verifyOrder', body: {
        "phoneNumber": phoneNumber,
        "operations": operations,
        "otp": otp
      });
      var body = json.decode(response.body);
      return body;
    } catch (e) {
      print(e);
    } finally {
      client.close();
    }
  }

  Future apiCheckConfirm({
    String operations,
  }) async {
    var client = http.Client();
    try {
      final response = await http.post(Env.apiHCS + 'checkPaid', body: {
        "operations": operations,
      });
      var body = json.decode(response.body);
      return body;
    } catch (e) {
      print(e);
    } finally {
      client.close();
    }
  }
}

==> likepoint_payment-0.0.7.tar.gz: lib/middle_ware/middle_payment.dart <==
import 'dart:convert';

import 'package:http/http.dart' as http;
import 'package:likepoint_payment/app_config.dart';

abstract class HTTP {
  Future apiCreateOrder(
      {String phone, String amount, String bu, String billCode, String title});
  Future apiSendConfirm({String phoneNumber, String operations, String otp});
  Future apiCheckConfirm({String operations});
}

class CallHTTP implements HTTP {
  Future apiCreateOrder(
      {String phone,
      String amount,
      String bu,
      String billCode,
      String title}) async {
    var client = http.Client();
    try {
      var url = Uri.parse(Env.apiHCS + 'createOrder');
      var map = {
        "phoneNumber": phone,
        "amount": amount,
        "BU": bu,
        "billcode": billCode,
        "title": title,
      };
      final response = await http.post(url, body: map);
      var body = json.decode(response.body);
      return body;
    } catch (e) {
      print(e);
    } finally {
      client.close();
    }
  }

  Future apiSendConfirm({
    String phoneNumber,
    String operations,
    String otp,
  }) async {
    var client = http.Client();
    try {
      var url = Uri.parse(Env.apiHCS + 'verifyOrder');
      var map = {
        "phoneNumber": phoneNumber,
        "operations": operations,
        "otp": otp
      };
      final response = await http.post(url, body: map);
      var body = json.decode(response.body);
      return body;
    } catch (e) {
      print(e);
    } finally {
      client.close();
    }
  }

  Future apiCheckConfirm({
    String operations,
  }) async {
    var client = http.Client();
    try {
      var url = Uri.parse(Env.apiHCS + 'checkPaid');
      var map = {
        "operations": operations,
      };
      final response = await http.post(url, body: map);
      var body = json.decode(response.body);
      return body;
    } catch (e) {
      print(e);
    } finally {
      client.close();
    }
  }
}
